@@ -141,22 +141,25 @@ class MultiRMLPDFWriter(BaseFileWriter):
     Multiple output pdf writer...
 
     Example of use :
-                        <node type="consumer" pluginname="multirmlpdfwriter" name="pdf_report">
-                            <encoding>UTF-8</encoding>
-                            <target_filename>myreport.pdf</target_filename>
-                            <document>
-                                <part>
-                                    <template type="plugin" module="foo">introduction</template>
-                                </part>
-                                <part type="multiple">
-                                    <expression>item.error_type</expression>
-                                    <template type="plugin" module="foo">error_type</template>
-                                </part>
-                                <part>
-                                    <template type="plugin" module="foo">footer</template>
-                                </part>
-                            </document>
-                        </node>
+    
+        .. code-block:: xml
+        
+            <node type="consumer" pluginname="multirmlpdfwriter" name="pdf_report">
+                <encoding>UTF-8</encoding>
+                <target_filename>myreport.pdf</target_filename>
+                <document>
+                    <part>
+                        <template type="plugin" module="foo">introduction</template>
+                    </part>
+                    <part type="multiple">
+                        <expression>item.error_type</expression>
+                        <template type="plugin" module="foo">error_type</template>
+                    </part>
+                    <part>
+                        <template type="plugin" module="foo">footer</template>
+                    </part>
+                </document>
+            </node>
                             """
 
     name = "multirmlpdfwriter"
@@ -174,8 +177,6 @@ class MultiRMLPDFWriter(BaseFileWriter):
         self.name = component_name
 
         self.encoding = self.get_config_key('encoding', 'UTF-8')
-        self.final_target_filename = self.get_config_key('target_filename',
-                                                         'report.pdf')
 
         self.init_document_definition()
 
@@ -336,7 +337,7 @@ class MultiRMLPDFWriter(BaseFileWriter):
         values = increment_input_count(values)
 
         self.final_target_filename = self.get_config_key('target_filename',
-                                                         'data.xml')
+                                                         'report.pdf')
         self.renderers = list()
         self.burnt_sources = list()
         assert len(self.document_definition) >= 1, "You should define at least one part in the document"
@@ -416,7 +417,7 @@ class MultiRMLPDFWriter(BaseFileWriter):
 
         if self.factory.tempfiles:
             self.factory.reorder_tempfiles([item[2] for item in sorted(self.renderers) if item[2] is not None])
-            self.factory.render_document(self.get_output_filename(self.final_target_filename))
+            self.factory.render_document(self.prepare_filename(self.final_target_filename))
 
         yield True
 
